summaryrefslogtreecommitdiff
path: root/ext/snmp
diff options
context:
space:
mode:
authorBoris Lytochkin <lytboris@php.net>2011-07-17 14:06:05 +0000
committerBoris Lytochkin <lytboris@php.net>2011-07-17 14:06:05 +0000
commitcc1ccefc0dc62b1736ac08a78dd7d614e912eb0c (patch)
tree06629a2199e9f02a004099ff655c559d719827a6 /ext/snmp
parent7cdef345d5e39a3030a23ea39c810fa3177c1b8a (diff)
downloadphp-git-cc1ccefc0dc62b1736ac08a78dd7d614e912eb0c.tar.gz
backport r313324
Diffstat (limited to 'ext/snmp')
-rw-r--r--ext/snmp/snmp.c10
1 files changed, 6 insertions, 4 deletions
diff --git a/ext/snmp/snmp.c b/ext/snmp/snmp.c
index bc0651a202..d548cb43ec 100644
--- a/ext/snmp/snmp.c
+++ b/ext/snmp/snmp.c
@@ -339,10 +339,12 @@ ZEND_END_ARG_INFO()
ZEND_BEGIN_ARG_INFO_EX(arginfo_snmp_get, 0, 0, 1)
ZEND_ARG_INFO(0, object_id)
+ ZEND_ARG_INFO(0, use_orignames)
ZEND_END_ARG_INFO()
-ZEND_BEGIN_ARG_INFO_EX(arginfo_snmp_walk, 0, 0, 3)
+ZEND_BEGIN_ARG_INFO_EX(arginfo_snmp_walk, 0, 0, 4)
ZEND_ARG_INFO(0, object_id)
+ ZEND_ARG_INFO(0, suffix_keys)
ZEND_ARG_INFO(0, non_repeaters)
ZEND_ARG_INFO(0, max_repetitions)
ZEND_END_ARG_INFO()
@@ -1749,7 +1751,7 @@ PHP_METHOD(snmp, close)
}
/* }}} */
/* {{{ proto mixed SNMP::get_assoc(mixed object_id)
Fetch a SNMP object returing scalar for single OID and array of oid->value pairs for multi OID request */
PHP_METHOD(snmp, get)
{
@@ -1757,7 +1759,7 @@ PHP_METHOD(snmp, get)
}
/* }}} */
-/* {{{ proto mixed SNMP::getnext(mixed object_id)
+/* {{{ proto mixed SNMP::getnext(mixed object_id)
Fetch a SNMP object returing scalar for single OID and array of oid->value pairs for multi OID request */
PHP_METHOD(snmp, getnext)
{
@@ -1765,7 +1767,7 @@ PHP_METHOD(snmp, getnext)
}
/* }}} */
-/* {{{ proto mixed SNMP::walk(mixed object_id)
+/* {{{ proto mixed SNMP::walk(mixed object_id [, bool $suffix_as_key = FALSE [, int $non_repeaters [, int $max_repetitions ]]])
Return all objects including their respective object id withing the specified one as array of oid->value pairs */
PHP_METHOD(snmp, walk)
{
@@ -1749,7 +1751,7 @@ PHP_METHOD(snmp, close)
}
/* }}} */
-/* {{{ proto mixed SNMP::get_assoc(mixed object_id)
+/* {{{ proto mixed SNMP::get(mixed object_id [, bool preserve_keys])
Fetch a SNMP object returing scalar for single OID and array of oid->value pairs for multi OID request */
PHP_METHOD(snmp, get)